@@ -1,8 +1,7 @@
 use std::collections::HashMap;
-use std::marker::PhantomData;
 
 use crate::aggregate::{Aggregate, AggregateError};
-use crate::query::QueryProcessor;
+use crate::query::Query;
 use crate::store::EventStore;
 use crate::AggregateContext;
 
@@ -19,37 +18,29 @@ use crate::AggregateContext;
 ///
 /// To manage these tasks we use a `CqrsFramework`.
 ///
-pub struct CqrsFramework<A, ES, AC>
+pub struct CqrsFramework<A, ES>
 where
     A: Aggregate,
-    ES: EventStore<A, AC>,
-    AC: AggregateContext<A>,
+    ES: EventStore<A>,
 {
     store: ES,
-    query_processors: Vec<Box<dyn QueryProcessor<A>>>,
-    _phantom: PhantomData<AC>,
+    query_processors: Vec<Box<dyn Query<A>>>,
 }
 
-impl<A, ES, AC> CqrsFramework<A, ES, AC>
+impl<A, ES> CqrsFramework<A, ES>
 where
     A: Aggregate,
-    ES: EventStore<A, AC>,
-    AC: AggregateContext<A>,
+    ES: EventStore<A>,
 {
     /// Creates new framework for dispatching commands using the provided elements.
-    pub fn new(
-        store: ES,
-        query_processors: Vec<Box<dyn QueryProcessor<A>>>,
-    ) -> CqrsFramework<A, ES, AC>
+    pub fn new(store: ES, query_processors: Vec<Box<dyn Query<A>>>) -> CqrsFramework<A, ES>
     where
         A: Aggregate,
-        ES: EventStore<A, AC>,
-        AC: AggregateContext<A>,
+        ES: EventStore<A>,
     {
         CqrsFramework {
             store,
             query_processors,
-            _phantom: PhantomData,
         }
     }
     /// This applies a command to an aggregate. Executing a command
@@ -63,8 +54,13 @@ where
     ///
     /// # Error
     /// If an error is generated while processing the command this will be returned.
-    pub fn execute(&self, aggregate_id: &str, command: A::Command) -> Result<(), AggregateError> {
+    pub async fn execute(
+        &self,
+        aggregate_id: &str,
+        command: A::Command,
+    ) -> Result<(), AggregateError> {
         self.execute_with_metadata(aggregate_id, command, HashMap::new())
+            .await
     }
 
     /// This applies a command to an aggregate along with associated metadata. Executing a command
@@ -81,21 +77,22 @@ where
     /// an AggregateError being returned.
     ///
     /// If successful the events produced will be applied to the configured `QueryProcessor`s.
-    pub fn execute_with_metadata(
+    pub async fn execute_with_metadata(
         &self,
         aggregate_id: &str,
         command: A::Command,
         metadata: HashMap<String, String>,
     ) -> Result<(), AggregateError> {
-        let aggregate_context = self.store.load_aggregate(aggregate_id);
+        let aggregate_context = self.store.load_aggregate(aggregate_id).await;
         let aggregate = aggregate_context.aggregate();
         let resultant_events = aggregate.handle(command)?;
         let committed_events = self
             .store
-            .commit(resultant_events, aggregate_context, metadata)?;
+            .commit(resultant_events, aggregate_context, metadata)
+            .await?;
         for processor in &self.query_processors {
             let dispatch_events = committed_events.as_slice();
-            processor.dispatch(aggregate_id, dispatch_events);
+            processor.dispatch(aggregate_id, dispatch_events).await;
         }
         Ok(())
     }
