@@ -1,3 +1,4 @@
+use async_trait::async_trait;
 use std::fmt::Debug;
 
 use serde::de::DeserializeOwned;
@@ -9,10 +10,11 @@ use crate::event::EventEnvelope;
 /// Each CQRS platform should have one or more `QueryProcessor`s where it will distribute committed
 /// events, it is the responsibility of the `QueryProcessor` to update any interested
 /// queries.
-pub trait QueryProcessor<A: Aggregate>: Send + Sync {
+#[async_trait]
+pub trait Query<A: Aggregate>: Send + Sync {
     /// Events will be dispatched here immediately after being committed for the downstream queries
     /// to be updated.
-    fn dispatch(&self, aggregate_id: &str, events: &[EventEnvelope<A>]);
+    async fn dispatch(&self, aggregate_id: &str, events: &[EventEnvelope<A>]);
 }
 
 /// A `Query` is a read element in a CQRS system. As events are emitted multiple downstream queries
@@ -21,8 +23,8 @@ pub trait QueryProcessor<A: Aggregate>: Send + Sync {
 ///
 /// Queries are generally serialized for persistence, usually in a standard database, but a query
 /// could also utilize messaging platform or other asynchronous, eventually-consistent systems.
-pub trait Query<A: Aggregate>: Debug + Default + Serialize + DeserializeOwned {
-    /// Each implemented query is responsible for updating its stated based on events passed via
+pub trait View<A: Aggregate>: Debug + Default + Serialize + DeserializeOwned {
+    /// Each implemented query is responsible for updating its state based on events passed via
     /// this method.
     fn update(&mut self, event: &EventEnvelope<A>);
 }
